==> elgg-3.0.5.zip: elgg-3.0.5/mod/messages/languages/it.php <==
<?php
return array(
	/**
	* Menu items and titles
	*/

	'messages' => "Messaggi",
	'messages:unreadcount' => "%s da leggere",
	'messages:user' => "Messaggi in arrivo per %s",
	'messages:inbox' => "In arrivo",
	'messages:sent' => "Inviati",
	'messages:message' => "Messaggio",
	'messages:title' => "Oggetto",
	'messages:to:help' => "Scrivi il nome utente del destinatario qui.",
	'messages:inbox' => "In arrivo",
	'messages:sendmessage' => "Invia un messaggio",
	'messages:add' => "Scrivi un messaggio",
	'messages:sentmessages' => "Messaggi inviati",
	'messages:toggle' => 'Inverti selezione a tutti',
	'messages:markread' => 'Segna come già letto',

	'notification:method:site' => 'Sito',

	'messages:error' => 'Si è verificato un errore salvando il messaggio. Per favore riprova.',

	'item:object:messages' => 'Message',
	'collection:object:messages' => 'Messages',

	/**
	* Status messages
	*/

	'messages:posted' => "Il messaggio è stato inviato.",
	'messages:success:delete:single' => 'Messaggio eliminato',
	'messages:success:delete' => 'Messaggi eliminati',
	'messages:success:read' => 'Messaggi contrassegnati come letti',
	'messages:error:messages_not_selected' => 'Nessun messaggio selezionato',
	'messages:error:delete:single' => 'Impossibile cancellare il messaggio',

	/**
	* Email messages
	*/

	'messages:email:subject' => 'Hai un nuovo messaggio!',
	'messages:email:body' => "You have a new message from %s.

It reads:

%s

To view your messages, click here:
%s

To send %s a message, click here:
%s",

	/**
	* Error messages
	*/

	'messages:blank' => "Devi scrivere qualcosa nel messaggio per poterlo salvare.",
	'messages:nomessages' => "Non ci sono messaggi.",
	'messages:user:nonexist' => "Impossibile trovare il destinatario nel database degli utenti.",
	'messages:user:blank' => "Non hai specificato a chi inviare il messaggio.",
	'messages:user:self' => "Non puoi inviare un messaggio a te stesso/a.",

	'messages:deleted_sender' => 'Utente eliminato',

);

==> elgg-3.3.20.zip: elgg-3.3.20/mod/messages/languages/it.php <==
<?php
/**
 * Translation file
 *
 * Note: don't change the return array to short notation because Transifex can't handle those during `tx push -s`
 */

return array(
	/**
	* Menu items and titles
	*/

	'messages' => "Messaggi",
	'messages:unreadcount' => "%s da leggere",
	'messages:user' => "Messaggi in arrivo per %s",
	'messages:inbox' => "In arrivo",
	'messages:sent' => "Inviati",
	'messages:message' => "Messaggio",
	'messages:title' => "Oggetto",
	'messages:to:help' => "Scrivi il nome utente del destinatario qui.",
	'messages:inbox' => "In arrivo",
	'messages:sendmessage' => "Invia un messaggio",
	'messages:add' => "Scrivi un messaggio",
	'messages:sentmessages' => "Messaggi inviati",
	'messages:toggle' => 'Inverti selezione a tutti',
	'messages:markread' => 'Segna come già letto',

	'notification:method:site' => 'Sito',

	'messages:error' => 'Si è verificato un errore salvando il messaggio. Per favore riprova.',

	'item:object:messages' => 'Messaggio',
	'collection:object:messages' => 'Messaggi',

	/**
	* Status messages
	*/

	'messages:posted' => "Il messaggio è stato inviato.",
	'messages:success:delete:single' => 'Messaggio eliminato',
	'messages:success:delete' => 'Messaggi eliminati',
	'messages:success:read' => 'Messaggi contrassegnati come letti',
	'messages:error:messages_not_selected' => 'Nessun messaggio selezionato',
	'messages:error:delete:single' => 'Impossibile cancellare il messaggio',

	/**
	* Email messages
	*/

	'messages:email:subject' => 'Hai un nuovo messaggio!',
	'messages:email:body' => "You have a new message from %s.

It reads:

%s

To view your messages, click here:
%s

To send %s a message, click here:
%s",

	/**
	* Error messages
	*/

	'messages:blank' => "Devi scrivere qualcosa nel messaggio per poterlo salvare.",
	'messages:nomessages' => "Non ci sono messaggi.",
	'messages:user:nonexist' => "Impossibile trovare il destinatario nel database degli utenti.",
	'messages:user:blank' => "Non hai specificato a chi inviare il messaggio.",
	'messages:user:self' => "Non puoi inviare un messaggio a te stesso/a.",

	'messages:deleted_sender' => 'Utente eliminato',

);
